@@ -15,13 +15,19 @@ def start(last=False):
     Returns the first date of the current quarter by default.
     Use last=True to get the first date of the last quarter.
     """
-    quarter = current_quarter()
+    quarter = 4
+
     year = dt.date.today().year
-    starts = {1:4, 2:7,  3:10,  4:1}
-    if last:
-        if quarter == 4:
-            year -= 1
-        quarter -= 1
+
+    starts = {1: 4, 2: 7, 3: 10, 4: 1}
+    if last == False:
+        quarter = current_quarter()
+    else:
+        if current_quarter() > 1:
+            quarter == current_quarter() - 1
+        else:
+            pass
+
     return dt.date(year, starts[quarter], 1)
 
 
